Crate kcr_snapshot_storage_k8s_io

Crate kcr_snapshot_storage_k8s_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the snapshot.storage.k8s.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

snapshot.storage.k8s.io/v1

  • VolumeSnapshotClass
  • VolumeSnapshotContent
  • VolumeSnapshot

snapshot.storage.k8s.io/v1beta1

  • VolumeSnapshotClass
  • VolumeSnapshotContent
  • VolumeSnapshot

Modules

v1
v1beta1