This crate contains kube-rs compatible bindings for Kubernetes custom resources for the snapshot.storage.k8s.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
snapshot.storage.k8s.io/v1
VolumeSnapshotClassVolumeSnapshotContentVolumeSnapshot
snapshot.storage.k8s.io/v1beta1
VolumeSnapshotClassVolumeSnapshotContentVolumeSnapshot